@@ -1,3 +1,5 @@
+#!/usr/bin/env python
+# -*- coding: utf-8 -*-
 from .settings import (adsorbate_elements,
                        site_heights,
                        adsorbate_formulas)
@@ -174,7 +176,7 @@ class ClusterAdsorbateCoverage(object):
         self.hetero_site_list = deepcopy(cas.site_list)
 
         self.label_list = ['0'] * len(self.hetero_site_list)
-        self.populate_occupied_sites()
+        self.populate_hetero_site_list()
 
         if self.ads_ids:
             self.labels = self.get_occupied_labels()
@@ -252,7 +254,7 @@ class ClusterAdsorbateCoverage(object):
 
         return np.asarray(conn_mat) 
 
-    def populate_occupied_sites(self):
+    def populate_hetero_site_list(self):
         """Find all the occupied sites, identify the adsorbate coverage
         of those sites and collect in a heterogeneous site list."""
 
@@ -744,7 +746,7 @@ class SlabAdsorbateCoverage(object):
         {'site': 'bridge', 'surface': 'fcc211', 'morphology': 'tc-cc-h', 
          'position': array([ 2.08423447,  3.82898322, 12.00043756]), 
          'normal': array([-0.33333333,  0.        ,  0.94280904]), 
-         'indices': (4, 7), 'composition': 'CuAu', 'subsurf_index': None, 
+         'indices': (4, 7), 'composition': 'AuCu', 'subsurf_index': None, 
          'subsurf_element': None, 'label': '17OH', 'bonding_index': 40, 
          'bond_length': 1.43783658, 'adsorbate': 'CH3OH', 
          'fragment': 'OH', 'adsorbate_indices': (36, 37, 38, 39, 40, 41), 
@@ -809,7 +811,7 @@ class SlabAdsorbateCoverage(object):
         self.hetero_site_list = deepcopy(sas.site_list)
 
         self.label_list = ['0'] * len(self.hetero_site_list)
-        self.populate_occupied_sites()
+        self.populate_hetero_site_list()
 
         if self.ads_ids:
             self.labels = self.get_occupied_labels() 
@@ -887,7 +889,7 @@ class SlabAdsorbateCoverage(object):
 
         return np.asarray(conn_mat) 
 
-    def populate_occupied_sites(self):
+    def populate_hetero_site_list(self):
         """Find all the occupied sites, identify the adsorbate coverage
         of those sites and collect in a heterogeneous site list."""
 
