@@ -1,9 +1,11 @@
+#!/usr/bin/env python
+# -*- coding: utf-8 -*-
 """Adsorbate procreation operators that adds an adsorbate to the surface of 
 a particle or given structure."""
 from ..settings import (adsorbate_elements, 
-                        adsorbate_molecule, 
                         site_heights)
-from ..utilities import (is_list_or_tuple, 
+from ..utilities import (custom_warning, 
+                         is_list_or_tuple, 
                          atoms_too_close_after_addition)
 from ..adsorption_sites import (ClusterAdsorptionSites, 
                                 SlabAdsorptionSites)
@@ -14,13 +16,15 @@ from ..build.action import (add_adsorbate_to_site,
                             remove_adsorbates_from_sites)
 from ase.ga.offspring_creator import OffspringCreator
 from ase.formula import Formula
-from ase import Atoms, Atom
+from ase import Atoms
 from asap3 import FullNeighborList
-from asap3 import EMT as asapEMT
 from operator import attrgetter
 from itertools import chain
+from copy import deepcopy
 import numpy as np
+import warnings
 import random
+warnings.formatwarning = custom_warning
 
 
 class AdsorbateOperator(OffspringCreator):
@@ -174,7 +178,7 @@ class AdsorbateOperator(OffspringCreator):
             if i >= len(hetero_site_list):
                 if return_site_index:
                     return False
-                print('Removal not possible, will add instead')
+                warnings.warn('Removal not possible, will add instead')
                 return self.add_adsorbate(atoms, hetero_site_list, site_heights)
 
             # Remove adsorbate from the correct position. Remove the fragment
@@ -370,7 +374,7 @@ class AddAdsorbate(AdsorbateOperator):
 
         if True in indi.pbc:
             if self.adsorption_sites is not None:
-                sas = self.adsorption_sites
+                sas = deepcopy(self.adsorption_sites)
                 sas.update(indi)
             else:
                 sas = SlabAdsorptionSites(indi, **self.kwargs)
@@ -378,7 +382,7 @@ class AddAdsorbate(AdsorbateOperator):
                                         self.subtract_heights, dmax=self.dmax)
         else:
             if self.adsorption_sites is not None:
-                sas = self.adsorption_sites
+                sas = deepcopy(self.adsorption_sites)
                 sas.update(indi)
             else:
                 sas = ClusterAdsorptionSites(indi, **self.kwargs)
@@ -518,7 +522,7 @@ class RemoveAdsorbate(AdsorbateOperator):
 
         if True in indi.pbc:
             if self.adsorption_sites is not None:
-                sas = self.adsorption_sites
+                sas = deepcopy(self.adsorption_sites)
                 sas.update(indi)
             else:
                 sas = SlabAdsorptionSites(indi, **self.kwargs)
@@ -526,7 +530,7 @@ class RemoveAdsorbate(AdsorbateOperator):
                                         self.subtract_heights, dmax=self.dmax)
         else:
             if self.adsorption_sites is not None:
-                sas = self.adsorption_sites
+                sas = deepcopy(self.adsorption_sites)
                 sas.update(indi)
             else:
                 sas = ClusterAdsorptionSites(indi, **self.kwargs)
@@ -690,7 +694,7 @@ class MoveAdsorbate(AdsorbateOperator):
 
         if True in indi.pbc:
             if self.adsorption_sites is not None:
-                sas = self.adsorption_sites
+                sas = deepcopy(self.adsorption_sites)
                 sas.update(indi)
             else:
                 sas = SlabAdsorptionSites(indi, **self.kwargs)
@@ -698,7 +702,7 @@ class MoveAdsorbate(AdsorbateOperator):
                                         self.subtract_heights, dmax=self.dmax)
         else:
             if self.adsorption_sites is not None:
-                sas = self.adsorption_sites
+                sas = deepcopy(self.adsorption_sites)
                 sas.update(indi)
             else:
                 sas = ClusterAdsorptionSites(indi, **self.kwargs) 
@@ -873,7 +877,7 @@ class ReplaceAdsorbate(AdsorbateOperator):
 
         if True in indi.pbc:
             if self.adsorption_sites is not None:
-                sas = self.adsorption_sites
+                sas = deepcopy(self.adsorption_sites)
                 sas.update(indi)
             else:
                 sas = SlabAdsorptionSites(indi, **self.kwargs)
@@ -881,7 +885,7 @@ class ReplaceAdsorbate(AdsorbateOperator):
                                         self.subtract_heights, dmax=self.dmax)
         else:
             if self.adsorption_sites is not None:
-                sas = self.adsorption_sites
+                sas = deepcopy(self.adsorption_sites)
                 sas.update(indi)
             else:
                 sas = ClusterAdsorptionSites(indi, **self.kwargs) 
@@ -1035,7 +1039,7 @@ class ReplaceAdsorbateSpecies(AdsorbateOperator):
 
         if True in indi.pbc:
             if self.adsorption_sites is not None:
-                sas = self.adsorption_sites
+                sas = deepcopy(self.adsorption_sites)
                 sas.update(indi)
             else:
                 sas = SlabAdsorptionSites(indi, **self.kwargs)
@@ -1043,7 +1047,7 @@ class ReplaceAdsorbateSpecies(AdsorbateOperator):
                                         self.subtract_heights, dmax=self.dmax)
         else:
             if self.adsorption_sites is not None:
-                sas = self.adsorption_sites
+                sas = deepcopy(self.adsorption_sites)
                 sas.update(indi)
             else:
                 sas = ClusterAdsorptionSites(indi, **self.kwargs) 
@@ -1225,7 +1229,7 @@ class CutSpliceCrossoverWithAdsorbates(AdsorbateOperator):
         
         if self.rvecs is not None:
             if not isinstance(self.rvecs, list):
-                print('Rotation vectors are not a list, skipping rotation')
+                warnings.warn('Rotation vectors are not a list, skipping rotation')
             else:
                 vec = random.choice(self.rvecs)
                 try:
@@ -1619,7 +1623,7 @@ class SimpleCutSpliceCrossoverWithAdsorbates(AdsorbateOperator):
         # Place adsorbates from half of m and remove adsorbates from
         # half of f
         if self.adsorption_sites is not None:
-            cas = self.adsorption_sites
+            cas = deepcopy(self.adsorption_sites)
             cas.update(indi)
         else:
             cas = ClusterAdsorptionSites(indi, **self.kwargs) 
